import SkribblClient from "../logic/SkribblClient.js";
import {CustomElement} from "../util/Util.js";

/**
 * Custom element `<skribbl-settings>` for the settings that appear in the lobby of the game.
 */
export default class SkribblSettings extends CustomElement {
	/**
	 * @param {SkribblClient} client
	 */
	constructor(client){
		super();
		this.attachShadow({mode:"open"});
		this.shadowRoot.innerHTML = `
			<style>
				:host {
					display: block;
					background: #ffffff;
					border-radius: 10px;
					padding: 15px;
				}
				h2 {
					margin: 0;
					text-align: center;
				}
				select {
					display: block;
					margin: 3px 5px 5px 5px;
					padding: 3px;
					width: 100%;
				}
				button {
					padding: 8px 25px;
					font-size: 20px;
					background: orange;
					color: white;
					border: none;
					border-radius: 4px;
					cursor: pointer;
				}
				button:disabled {
					cursor: default;
					background: #dfa580;
				}
			</style>
			<h2>Lobby</h2>
			<b>Rounds:</b>
			<select>
				<option value="2">2</option>
				<option value="3" selected="">3</option>
				<option value="4">4</option>
				<option value="5">5</option>
				<option value="6">6</option>
				<option value="7">7</option>
				<option value="8">8</option>
				<option value="9">9</option>
				<option value="10">10</option>
			</select><br>
			<b>Draw time:</b>
			<select>
				<option value="30">30s</option>
				<option value="45">45s</option>
				<option value="60">60s</option>
				<option value="90">90s</option>
				<option value="120">120s</option>
				<option value="180" selected="">180s</option>
				<option value="240">240s</option>
			</select><br>
			<div style="text-align:center">
				<button>Start Game</button>
			</div>
		`;
		this._client = client;
		this._roundsInput = this.shadowRoot.querySelectorAll("select")[0];
		this._drawTimeInput = this.shadowRoot.querySelectorAll("select")[1];
		this._startButton = this.shadowRoot.querySelector("button");
		client.isHost.onChange(host=>{
			this._roundsInput.disabled = !host;
			this._drawTimeInput.disabled = !host;
			this._startButton.disabled = !host;
		},{onlyWhen:this.connected});
		client.settings.onChange(settings=>{
			this._roundsInput.value = settings.rounds.toString();
			this._drawTimeInput.value = settings.drawTime.toString();
		},{onlyWhen:this.connected});
		this._startButton.addEventListener("click",e=>{
			this._client.startGame();
		});
		this._roundsInput.addEventListener("change",e=>{
			this._client.setSettings({rounds:parseInt(this._roundsInput.value)});
		});
		this._drawTimeInput.addEventListener("change",e=>{
			this._client.setSettings({drawTime:parseInt(this._drawTimeInput.value)});
		});
	}
}
customElements.define("skribbl-settings",SkribblSettings);